summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorCamVan Nguyen <ctnguyen@us.ibm.com>2012-08-15 16:01:22 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2012-08-16 13:54:43 -0500
commit1681d8660846d58472bb717917ec383b49d69faf (patch)
tree9d5449b8aab65fc06bd7c4967db7953be12b8116 /src/include
parent3afee991ccf79716b952706edfdf128b16154810 (diff)
downloadtalos-hostboot-1681d8660846d58472bb717917ec383b49d69faf.tar.gz
talos-hostboot-1681d8660846d58472bb717917ec383b49d69faf.zip
Updates to IPL flow v1.08
Change-Id: I496b5739f625dd5111a5cdd144e89dcd43ad1986 RTC: 45712 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/1533 Tested-by: Jenkins Server Reviewed-by: Van H. Lee <vanlee@us.ibm.com> Reviewed-by: MIKE J. JONES <mjjones@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/isteps/istep08list.H88
-rw-r--r--src/include/usr/isteps/istep11list.H44
-rw-r--r--src/include/usr/isteps/istep12list.H14
-rw-r--r--src/include/usr/isteps/istep13list.H46
-rw-r--r--src/include/usr/isteps/istep14list.H56
-rw-r--r--src/include/usr/isteps/istep15list.H50
-rw-r--r--src/include/usr/isteps/istep18list.H72
-rw-r--r--src/include/usr/isteps/istep20list.H87
-rw-r--r--src/include/usr/isteps/istepmasterlist.H49
9 files changed, 220 insertions, 286 deletions
diff --git a/src/include/usr/isteps/istep08list.H b/src/include/usr/isteps/istep08list.H
index efe8104d9..b029a328f 100644
--- a/src/include/usr/isteps/istep08list.H
+++ b/src/include/usr/isteps/istep08list.H
@@ -1,26 +1,26 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep08list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
-
+/* IBM_PROLOG_BEGIN_TAG
+ * This is an automatically generated prolog.
+ *
+ * $Source: src/include/usr/isteps/istep08list.H $
+ *
+ * IBM CONFIDENTIAL
+ *
+ * COPYRIGHT International Business Machines Corp. 2012
+ *
+ * p1
+ *
+ * Object Code Only (OCO) source materials
+ * Licensed Internal Code Source Materials
+ * IBM HostBoot Licensed Internal Code
+ *
+ * The source code for this program is not published or other-
+ * wise divested of its trade secrets, irrespective of what has
+ * been deposited with the U.S. Copyright Office.
+ *
+ * Origin: 30
+ *
+ * IBM_PROLOG_END_TAG
+ */
#ifndef __ISTEPS_ISTEP08LIST_H
#define __ISTEPS_ISTEP08LIST_H
@@ -28,19 +28,23 @@
* @file istep08list.H
*
* IStep 08 EDI, EI Initialization
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.08 (08/13/12)
*
* 08.1 fabric_erepair
* : Restore Fabric/EDI Bus eRepair data
* 08.2 fabric_io_dccal
* : Calibrate Fabric/EDI interfaces
- * 08.3 fabric_io_run_training
+ * 08.3 fabric_pre_trainadv
+ * : Advanced pre EI/EDI training
+ * 08.4 fabric_io_run_training
* : Run training on internal buses
- * 08.4 host_startPRD_pbus
+ * 08.5 fabric_post_trainadv
+ * : Advanced post EI/EDI training
+ * 08.6 host_startPRD_pbus
* : Load PRD for powerbus domain
- * 08.5 host_attnlisten_proc
+ * 08.7 host_attnlisten_proc
* : Start listening for attentions
- * 08.6 proc_fab_iovalid
+ * 08.8 proc_fab_iovalid
* : Lower functional fences on local SMP
*
* *****************************************************************
@@ -93,7 +97,17 @@ namespace INITSERVICE
{
- ISTEPNAME(08,03,"fabric_io_run_training"),
+ ISTEPNAME(08,03,"fabric_pre_trainadv"),
+ EDI_EI_INITIALIZATION::call_fabric_pre_trainadv,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+
+
+ {
+ ISTEPNAME(08,04,"fabric_io_run_training"),
EDI_EI_INITIALIZATION::call_fabric_io_run_training,
{
START_FN,
@@ -103,7 +117,17 @@ namespace INITSERVICE
{
- ISTEPNAME(08,04,"host_startPRD_pbus"),
+ ISTEPNAME(08,05,"fabric_post_trainadv"),
+ EDI_EI_INITIALIZATION::call_fabric_post_trainadv,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+
+
+ {
+ ISTEPNAME(08,06,"host_startPRD_pbus"),
EDI_EI_INITIALIZATION::call_host_startPRD_pbus,
{
START_FN,
@@ -113,7 +137,7 @@ namespace INITSERVICE
{
- ISTEPNAME(08,05,"host_attnlisten_proc"),
+ ISTEPNAME(08,07,"host_attnlisten_proc"),
EDI_EI_INITIALIZATION::call_host_attnlisten_proc,
{
START_FN,
@@ -123,7 +147,7 @@ namespace INITSERVICE
{
- ISTEPNAME(08,06,"proc_fab_iovalid"),
+ ISTEPNAME(08,08,"proc_fab_iovalid"),
EDI_EI_INITIALIZATION::call_proc_fab_iovalid,
{
START_FN,
diff --git a/src/include/usr/isteps/istep11list.H b/src/include/usr/isteps/istep11list.H
index 3436c90d0..31b174de2 100644
--- a/src/include/usr/isteps/istep11list.H
+++ b/src/include/usr/isteps/istep11list.H
@@ -26,7 +26,7 @@
/**
* list of functions called for DMI Training - ISTEP 11 according to Dean's
- * HostBoot IPL Flow v1.05
+ * HostBoot IPL Flow v1.08
*
* 11.1. dmi_scominit
* : Scom setup on centaur
@@ -34,15 +34,19 @@
* : Restore EDI Bus eRepair data
* 11.3. dmi_io_dccal
* : Calibrate DMI interfaces
- * 11.4. dmi_io_run_training
+ * 11.4. dmi_pre_trainadv
+ * : Advanced pre DMI training
+ * 11.5. dmi_io_run_training
* : Run training on MC buses
- * 11.5. proc_cen_framelock
+ * 11.6. dmi_post_trainadv
+ * : Advanced post DMI training
+ * 11.7. proc_cen_framelock
* : Initialize EDI Frame
- * 11.6. host_startPRD_dmi
+ * 11.8. host_startPRD_dmi
* : Load PRD for DMI domain
- * 11.7. host_attnlisten_cen
+ * 11.9. host_attnlisten_cen
* : Start listening for attentions
- * 11.8. cen_set_inband_addr
+ * 11.10. cen_set_inband_addr
* : Set the Inband base addresses
*/
@@ -100,7 +104,15 @@ const TaskInfo g_istep11[] = {
}
},
{
- ISTEPNAME(11,04,"dmi_io_run_training"), // substep name
+ ISTEPNAME(11,04,"dmi_pre_trainadv"), // substep name
+ DMI_TRAINING::call_dmi_pre_trainadv, // pointer to fn
+ {
+ START_FN, // task type
+ EXT_IMAGE, // Extended Module
+ }
+ },
+ {
+ ISTEPNAME(11,05,"dmi_io_run_training"), // substep name
DMI_TRAINING::call_dmi_io_run_training, // pointer to fn
{
START_FN, // task type
@@ -108,7 +120,15 @@ const TaskInfo g_istep11[] = {
}
},
{
- ISTEPNAME(11,05,"proc_cen_framelock"), // substep name
+ ISTEPNAME(11,06,"dmi_post_trainadv"), // substep name
+ DMI_TRAINING::call_dmi_post_trainadv, // pointer to fn
+ {
+ START_FN, // task type
+ EXT_IMAGE, // Extended Module
+ }
+ },
+ {
+ ISTEPNAME(11,07,"proc_cen_framelock"), // substep name
DMI_TRAINING::call_proc_cen_framelock, // pointer to fn
{
START_FN, // task type
@@ -116,7 +136,7 @@ const TaskInfo g_istep11[] = {
}
},
{
- ISTEPNAME(11,06,"host_startPRD_dmi"), // substep name
+ ISTEPNAME(11,08,"host_startPRD_dmi"), // substep name
DMI_TRAINING::call_host_startPRD_dmi, // pointer to fn
{
START_FN, // task type
@@ -124,7 +144,7 @@ const TaskInfo g_istep11[] = {
}
},
{
- ISTEPNAME(11,07,"host_attnlisten_cen"), // substep name
+ ISTEPNAME(11,09,"host_attnlisten_cen"), // substep name
DMI_TRAINING::call_host_attnlisten_cen, // pointer to fn
{
START_FN, // task type
@@ -132,8 +152,8 @@ const TaskInfo g_istep11[] = {
}
},
{
- ISTEPNAME(11,08,"cen_set_inband_addr"), // substep name
- DMI_TRAINING::call_cen_set_inband_addr, // pointer to fn
+ ISTEPNAME(11,10,"cen_set_inband_addr"), // substep name
+ DMI_TRAINING::call_cen_set_inband_addr, // pointer to fn
{
START_FN, // task type
EXT_IMAGE, // Extended Module
diff --git a/src/include/usr/isteps/istep12list.H b/src/include/usr/isteps/istep12list.H
index 3e95ae824..0fce06b7a 100644
--- a/src/include/usr/isteps/istep12list.H
+++ b/src/include/usr/isteps/istep12list.H
@@ -27,8 +27,8 @@
/**
* @file istep12list.H
*
- * IStep 12 Step 12 MC Init
- * IPL FLow Doc v0.99 (02/10/12)
+ * IStep 12 Step 12 MC Config
+ * IPL FLow Doc v1.08 (08/13/12)
*
* 12.1 host_collect_dimm_spd
* : Collect Master dimm SPD
@@ -52,7 +52,7 @@
#include <initservice/initsvcreasoncodes.H>
// include prototypes file
-#include "../../../usr/hwpf/hwp/mc_init/mc_init.H"
+#include "../../../usr/hwpf/hwp/mc_config/mc_config.H"
namespace INITSERVICE
{
@@ -69,7 +69,7 @@ const TaskInfo g_istep12[] = {
{
ISTEPNAME(12,01,"host_collect_dimm_spd"),
- MC_INIT::call_host_collect_dimm_spd,
+ MC_CONFIG::call_host_collect_dimm_spd,
{
START_FN,
EXT_IMAGE,
@@ -77,7 +77,7 @@ const TaskInfo g_istep12[] = {
},
{
ISTEPNAME(12,02,"mss_volt"),
- MC_INIT::call_mss_volt,
+ MC_CONFIG::call_mss_volt,
{
START_FN,
EXT_IMAGE,
@@ -85,7 +85,7 @@ const TaskInfo g_istep12[] = {
},
{
ISTEPNAME(12,03,"mss_freq"),
- MC_INIT::call_mss_freq,
+ MC_CONFIG::call_mss_freq,
{
START_FN,
EXT_IMAGE,
@@ -93,7 +93,7 @@ const TaskInfo g_istep12[] = {
},
{
ISTEPNAME(12,04,"mss_eff_config"),
- MC_INIT::call_mss_eff_config,
+ MC_CONFIG::call_mss_eff_config,
{
START_FN,
EXT_IMAGE,
diff --git a/src/include/usr/isteps/istep14list.H b/src/include/usr/isteps/istep14list.H
index 715b13ee8..efd697a3f 100644
--- a/src/include/usr/isteps/istep14list.H
+++ b/src/include/usr/isteps/istep14list.H
@@ -1,26 +1,26 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep14list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
-
+/* IBM_PROLOG_BEGIN_TAG
+ * This is an automatically generated prolog.
+ *
+ * $Source: src/include/usr/isteps/istep14list.H $
+ *
+ * IBM CONFIDENTIAL
+ *
+ * COPYRIGHT International Business Machines Corp. 2012
+ *
+ * p1
+ *
+ * Object Code Only (OCO) source materials
+ * Licensed Internal Code Source Materials
+ * IBM HostBoot Licensed Internal Code
+ *
+ * The source code for this program is not published or other-
+ * wise divested of its trade secrets, irrespective of what has
+ * been deposited with the U.S. Copyright Office.
+ *
+ * Origin: 30
+ *
+ * IBM_PROLOG_END_TAG
+ */
#ifndef __ISTEPS_ISTEP14LIST_H
#define __ISTEPS_ISTEP14LIST_H
@@ -28,7 +28,7 @@
* @file istep14list.H
*
* IStep 14 Dram Initialization
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.08 (08/13/12)
*
* 14.1 host_startPRD_dram
* : Load PRD for DRAM domain
@@ -42,8 +42,8 @@
* : Initialize the thermal sensor
* 14.6 proc_setup_bars
* : Setup Memory BARs
- * 14.7 proc_pbus_epsilon
- * : Set runtime epsilons
+ * 14.7 proc_pcie_config
+ * : Configure the PHBs
* 14.8 proc_exit_cache_contained
* : Allow execution from memory
*
@@ -137,8 +137,8 @@ namespace INITSERVICE
{
- ISTEPNAME(14,07,"proc_pbus_epsilon"),
- DRAM_INITIALIZATION::call_proc_pbus_epsilon,
+ ISTEPNAME(14,07,"proc_pcie_config"),
+ DRAM_INITIALIZATION::call_proc_pcie_config,
{
START_FN,
EXT_IMAGE,
diff --git a/src/include/usr/isteps/istep15list.H b/src/include/usr/isteps/istep15list.H
index 21ddc2d61..d50e48cec 100644
--- a/src/include/usr/isteps/istep15list.H
+++ b/src/include/usr/isteps/istep15list.H
@@ -1,26 +1,26 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep15list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
-
+/* IBM_PROLOG_BEGIN_TAG
+ * This is an automatically generated prolog.
+ *
+ * $Source: src/include/usr/isteps/istep15list.H $
+ *
+ * IBM CONFIDENTIAL
+ *
+ * COPYRIGHT International Business Machines Corp. 2012
+ *
+ * p1
+ *
+ * Object Code Only (OCO) source materials
+ * Licensed Internal Code Source Materials
+ * IBM HostBoot Licensed Internal Code
+ *
+ * The source code for this program is not published or other-
+ * wise divested of its trade secrets, irrespective of what has
+ * been deposited with the U.S. Copyright Office.
+ *
+ * Origin: 30
+ *
+ * IBM_PROLOG_END_TAG
+ */
#ifndef __ISTEPS_ISTEP15LIST_H
#define __ISTEPS_ISTEP15LIST_H
@@ -28,12 +28,12 @@
* @file istep15list.H
*
* IStep 15 Build Winkle Images
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.08 (08/13/12)
*
* 15.1 host_build_winkle
* : Build runtime winkle images
* 15.2 proc_set_pore_bar
- * : Place winkle images in memory
+ * : Tell SLW Eng where winkle image is
*
* *****************************************************************
* THIS FILE WAS GENERATED ON 2012-04-12:1228
diff --git a/src/include/usr/isteps/istep18list.H b/src/include/usr/isteps/istep18list.H
index 1ef4428bd..69a282c8b 100644
--- a/src/include/usr/isteps/istep18list.H
+++ b/src/include/usr/isteps/istep18list.H
@@ -1,26 +1,26 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep18list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
-
+/* IBM_PROLOG_BEGIN_TAG
+ * This is an automatically generated prolog.
+ *
+ * $Source: src/include/usr/isteps/istep18list.H $
+ *
+ * IBM CONFIDENTIAL
+ *
+ * COPYRIGHT International Business Machines Corp. 2012
+ *
+ * p1
+ *
+ * Object Code Only (OCO) source materials
+ * Licensed Internal Code Source Materials
+ * IBM HostBoot Licensed Internal Code
+ *
+ * The source code for this program is not published or other-
+ * wise divested of its trade secrets, irrespective of what has
+ * been deposited with the U.S. Copyright Office.
+ *
+ * Origin: 30
+ *
+ * IBM_PROLOG_END_TAG
+ */
#ifndef __ISTEPS_ISTEP18LIST_H
#define __ISTEPS_ISTEP18LIST_H
@@ -28,14 +28,10 @@
* @file istep18list.H
*
* IStep 18 Establish System SMP
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.08 (08/13/12)
*
* 18.8 host_coalesce_host
* : Create single host image
- * 18.9 proc_tod_setup
- * : Setup TOD
- * 18.10 proc_tod_init
- * : Init TOD
*
* *****************************************************************
* THIS FILE WAS PARTIALLY GENERATED ON 2012-04-11:1611
@@ -140,26 +136,6 @@ namespace INITSERVICE
},
- {
- ISTEPNAME(18,09,"proc_tod_setup"),
- ESTABLISH_SYSTEM_SMP::call_proc_tod_setup,
- {
- START_FN,
- EXT_IMAGE,
- }
- },
-
-
- {
- ISTEPNAME(18,10,"proc_tod_init"),
- ESTABLISH_SYSTEM_SMP::call_proc_tod_init,
- {
- START_FN,
- EXT_IMAGE,
- }
- },
-
-
// END OF LIST!
};
diff --git a/src/include/usr/isteps/istep20list.H b/src/include/usr/isteps/istep20list.H
deleted file mode 100644
index d7a86d57b..000000000
--- a/src/include/usr/isteps/istep20list.H
+++ /dev/null
@@ -1,87 +0,0 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep20list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
-
-#ifndef __ISTEPS_ISTEP20LIST_H
-#define __ISTEPS_ISTEP20LIST_H
-
-/**
- * @file istep20list.H
- *
- * IStep 20 Load Payload
- * IPL FLow Doc v1.01 (03/26/12)
- *
- * 20.1 host_load_payload
- * : Load payload
- *
- * *****************************************************************
- * THIS FILE WAS GENERATED ON 2012-04-11:1612
- * *****************************************************************
- *
- * Please see the note in initsvcstructs.H for description of
- * the ISTEPNAME macro.
- *
- */
-
-#include <initservice/initsvcstructs.H>
-#include <initservice/initsvcreasoncodes.H>
-
-// include prototypes file
-#include "../../../usr/hwpf/hwp/load_payload/load_payload.H"
-
-namespace INITSERVICE
-{
- const TaskInfo g_istep20[] = {
-
- {
-
- "", // dummy, index 0
- NULL,
- {
- NONE,
- EXT_IMAGE,
- }
- },
-
- {
- ISTEPNAME(20,01,"host_load_payload"),
- LOAD_PAYLOAD::call_host_load_payload,
- {
- START_FN,
- EXT_IMAGE,
- }
- },
-
-
- // END OF LIST!
-};
-
-// make a struct from the above with the number of items included
-const ExtTaskInfo g_istep20TaskList = {
- &(g_istep20[0]),
- ( sizeof(g_istep20)/sizeof(TaskInfo) ),
- NULL // later, depModules struct
-};
-
-}; // end namespace
-
-#endif
diff --git a/src/include/usr/isteps/istepmasterlist.H b/src/include/usr/isteps/istepmasterlist.H
index 4d01074cb..902ba4277 100644
--- a/src/include/usr/isteps/istepmasterlist.H
+++ b/src/include/usr/isteps/istepmasterlist.H
@@ -1,25 +1,26 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istepmasterlist.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2011
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
+/* IBM_PROLOG_BEGIN_TAG
+ * This is an automatically generated prolog.
+ *
+ * $Source: src/include/usr/isteps/istepmasterlist.H $
+ *
+ * IBM CONFIDENTIAL
+ *
+ * COPYRIGHT International Business Machines Corp. 2011-2012
+ *
+ * p1
+ *
+ * Object Code Only (OCO) source materials
+ * Licensed Internal Code Source Materials
+ * IBM HostBoot Licensed Internal Code
+ *
+ * The source code for this program is not published or other-
+ * wise divested of its trade secrets, irrespective of what has
+ * been deposited with the U.S. Copyright Office.
+ *
+ * Origin: 30
+ *
+ * IBM_PROLOG_END_TAG
+ */
#ifndef __ISTEPS_ISTEPMASTERLIST_H
#define __ISTEPS_ISTEPMASTERLIST_H
@@ -73,7 +74,7 @@
// istep 17, FSP only
#include "istep18list.H"
// istep 19, FSP only
-#include "istep20list.H"
+// istep 20, FSP only
#include "istep21list.H"
namespace INITSERVICE
@@ -101,7 +102,7 @@ const ExtTaskInfo g_isteps[] = {
{ NULL, 0, NULL}, // FSP IStep 17
INITSERVICE::g_istep18TaskList, // IStep 18
{ NULL, 0, NULL }, // FSP IStep 19
- INITSERVICE::g_istep20TaskList, // IStep 20
+ { NULL, 0, NULL }, // FSP IStep 20
INITSERVICE::g_istep21TaskList // IStep 21
//
// add further istep lists at the end.
OpenPOWER on IntegriCloud
diff --git a/src/include/usr/isteps/istep13list.H b/src/include/usr/isteps/istep13list.H
index 870427d8d..fe982d0e9 100644
--- a/src/include/usr/isteps/istep13list.H
+++ b/src/include/usr/isteps/istep13list.H
@@ -28,28 +28,28 @@
* @file istep13list.H
*
* IStep 13 Step 13 DRAM Training
- * IPL FLow Doc v0.99 (02/10/12)
+ * IPL FLow Doc v1.08 (08/13/12)
*
* 13.1 host_disable_vddr
* : Disable VDDR on CanContinue loops
* 13.2 mc_pll_setup
* : Setup PLL for MBAs
* 13.3 mem_startclocks
* : Start clocks on MBAs
* 13.4 host_enable_vddr
* : Enable the VDDR3 Voltage Rail
* 13.5 mss_scominit
* : Perform scom inits to MC and PHY
* 13.6 mss_ddr_phy_reset
* : Soft reset of DDR PHY macros
* 13.7 mss_draminit
* : Dram initialize
* 13.8 mss_draminit_training
* : Dram training
* 13.9 mss_draminit_trainadv
* : Advanced dram training
* 13.10 mss_draminit_mc
* : Hand off control to MC
*
* *****************************************************************
* THIS FILE WAS GENERATED ON 2012-02-27:2142
@@ -88,8 +88,8 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,02,"mc_pll_setup"),
- DRAM_TRAINING::call_mc_pll_setup,
+ ISTEPNAME(13,02,"mem_pll_setup"),
+ DRAM_TRAINING::call_mem_pll_setup,
{
START_FN,
EXT_IMAGE,
@@ -28,28 +28,28 @@
*
- * 13.1 host_disable_vddr
- * : Disable VDDR on CanContinue loops
- * 13.2 mc_pll_setup
- * : Setup PLL for MBAs
- * 13.3 mem_startclocks
- * : Start clocks on MBAs
- * 13.4 host_enable_vddr
- * : Enable the VDDR3 Voltage Rail
- * 13.5 mss_scominit
- * : Perform scom inits to MC and PHY
- * 13.6 mss_ddr_phy_reset
- * : Soft reset of DDR PHY macros
- * 13.7 mss_draminit
- * : Dram initialize
- * 13.8 mss_draminit_training
- * : Dram training
- * 13.9 mss_draminit_trainadv
- * : Advanced dram training
- * 13.10 mss_draminit_mc
- * : Hand off control to MC
+ * 13.1 host_disable_vddr
+ * : Disable VDDR on CanContinue loops
+ * 13.2 mem_pll_setup
+ * : Setup PLL for MBAs
+ * 13.3 mem_startclocks
+ * : Start clocks on MBAs
+ * 13.4 host_enable_vddr
+ * : Enable the VDDR3 Voltage Rail
+ * 13.5 mss_scominit
+ * : Perform scom inits to MC and PHY
+ * 13.6 mss_ddr_phy_reset
+ * : Soft reset of DDR PHY macros
+ * 13.7 mss_draminit
+ * : Dram initialize
+ * 13.8 mss_draminit_training
+ * : Dram training
+ * 13.9 mss_draminit_trainadv
+ * : Advanced dram training
+ * 13.10 mss_draminit_mc
+ * : Hand off control to MC
*
* *****************************************************************